@@ -448,13 +448,13 @@ class LegacyContact(
             log.debug("Roster push request by plugin ignored (--no-roster-push)")
             return
         try:
-            await self._set_roster(
+            await self.xmpp["xep_0356"].set_roster(
                 jid=self.user_jid, roster_items=self.get_roster_item()
             )
         except PermissionError:
             warnings.warn(
                 "Slidge does not have privileges to add contacts to the roster. Refer"
-                " to https://slidge.codeberg.page/docs/main/admin/privilege.html for"
+                " to https://slidge.im/docs/slidge/main/admin/privilege.html for"
                 " more info."
             )
             if config.ROSTER_PUSH_PRESENCE_SUBSCRIPTION_REQUEST_FALLBACK:
@@ -490,12 +490,6 @@ class LegacyContact(
                 nick,
             )
 
-    async def _set_roster(self, **kw):
-        try:
-            await self.xmpp["xep_0356"].set_roster(**kw)
-        except PermissionError:
-            await self.xmpp["xep_0356_old"].set_roster(**kw)
-
     def send_friend_request(self, text: Optional[str] = None):
         presence = self._make_presence(ptype="subscribe", pstatus=text, bare=True)
         self._send(presence, nick=True)
