@@ -254,6 +254,10 @@ class BaseGateway(
     http: aiohttp.ClientSession
 
     def __init__(self):
+        if config.COMPONENT_NAME:
+            self.COMPONENT_NAME = config.COMPONENT_NAME
+        if config.WELCOME_MESSAGE:
+            self.WELCOME_MESSAGE = config.WELCOME_MESSAGE
         self.log = log
         self.datetime_started = datetime.now()
         self.xmpp = self  # ugly hack to work with the BaseSender mixin :/
@@ -416,8 +420,14 @@ class BaseGateway(
         await self.plugin["xep_0115"].update_caps(jid=self.boundjid)
 
         if self.COMPONENT_AVATAR is not None:
-            cached_avatar = await avatar_cache.convert_or_get(self.COMPONENT_AVATAR)
-            self.avatar_pk = cached_avatar.pk
+            try:
+                cached_avatar = await avatar_cache.convert_or_get(self.COMPONENT_AVATAR)
+            except Exception as e:
+                log.exception("Could not set the component avatar.", exc_info=e)
+                cached_avatar = None
+            else:
+                assert cached_avatar is not None
+                self.avatar_pk = cached_avatar.pk
         else:
             cached_avatar = None
 
@@ -505,6 +515,7 @@ class BaseGateway(
     @timeit
     async def login_wrap(self, session: "BaseSession"):
         session.send_gateway_status("Logging in…", show="dnd")
+        session.is_logging_in = True
         try:
             status = await session.login()
         except Exception as e:
@@ -798,7 +809,9 @@ class BaseGateway(
 
     async def unregister_user(self, user: GatewayUser):
         self.send_presence(
-            pshow="busy", pstatus="You are not registered to this gateway anymore."
+            pshow="dnd",
+            pstatus="You unregistered from this gateway.",
+            pto=user.jid,
         )
         await self.xmpp.plugin["xep_0077"].api["user_remove"](None, None, user.jid)
         await self.xmpp.session_cls.kill_by_jid(user.jid)
@@ -903,7 +916,6 @@ SLIXMPP_PLUGINS = [
     "xep_0333",  # Chat markers
     "xep_0334",  # Message Processing Hints
     "xep_0356",  # Privileged Entity
-    "xep_0356_old",  # Privileged Entity (old namespace)
     "xep_0363",  # HTTP file upload
     "xep_0385",  # Stateless in-line media sharing
     "xep_0402",  # PEP Native Bookmarks
