@@ -58,6 +58,8 @@ class EngineMixin:
     def __init__(self, engine: Engine):
         self._engine = engine
 
+    # TODO: we should not have a global Session object but instead build Sessions with different parameters
+    #       depending on the context (startup, incoming XMPP event, incoming legacy event).
     @contextmanager
     def session(self, **session_kwargs) -> Iterator[Session]:
         global _session
@@ -696,6 +698,8 @@ class MultiStore(EngineMixin):
             ).scalar()
             if multi is None:
                 return []
+            if multi.legacy_ids_multi is None:
+                return []
             return [m.xmpp_id for m in multi.legacy_ids_multi.xmpp_ids]
 
     def set_xmpp_ids(
@@ -1070,6 +1074,7 @@ class ParticipantStore(EngineMixin):
                 .where(Participant.id == participant.pk)
                 .values(
                     resource=participant.jid.resource,
+                    nickname_no_illegal=participant._nickname_no_illegal,
                     affiliation=participant.affiliation,
                     role=participant.role,
                     presence_sent=participant._presence_sent,  # type:ignore
