@@ -70,6 +70,8 @@ class LegacyParticipant(
         is_system=False,
         role: MucRole = "participant",
         affiliation: MucAffiliation = "member",
+        resource: str | None = None,
+        nickname_no_illegal: str | None = None,
     ):
         self.session = session = muc.session
         self.xmpp = session.xmpp
@@ -83,7 +85,14 @@ class LegacyParticipant(
 
         self._nickname = nickname
 
-        self.__update_jid(nickname)
+        if resource is None:
+            self.__update_jid(nickname)
+        else:
+            assert nickname_no_illegal is not None
+            self._nickname_no_illegal = nickname_no_illegal
+            self.jid = JID(self.muc.jid)
+            self.jid.resource = resource
+
         log.debug("Instantiation of: %r", self)
 
         self.contact: Optional["LegacyContact"] = None
@@ -510,6 +519,8 @@ class LegacyParticipant(
             stored.nickname,
             role=stored.role,
             affiliation=stored.affiliation,
+            resource=stored.resource,
+            nickname_no_illegal=stored.nickname_no_illegal,
         )
         part.pk = stored.id
         if contact is not None:
