@@ -423,7 +423,7 @@ class LegacyMUC(
 
         if subject_setter == self._subject_setter:
             return
-        assert isinstance(subject_setter, str)
+        assert isinstance(subject_setter, str | None)
         self._subject_setter = subject_setter
         if self._updating_info:
             return
