@@ -747,6 +747,22 @@ class TestAimShakespeareBase(Base):
         )
         config.ADMINS = ()
 
+    def test_disco_adhoc_commands_as_unauthorized(self):
+        self.xmpp.jid_validator = re.compile("nothing")
+        self.recv(  # language=XML
+            f"""
+            <iq type='get'
+                from='admin@forbidden.lit/gajim'
+                to='{self.xmpp.boundjid.bare}'>
+              <query xmlns='http://jabber.org/protocol/disco#items'
+                     node='http://jabber.org/protocol/commands' />
+            </iq>
+            """
+        )
+        st = self.next_sent()
+        assert st["error"]["condition"] == "forbidden"
+        self.xmpp.jid_validator = re.compile(".*")
+
     def test_adhoc_forbidden_non_admin(self):
         with unittest.mock.patch(
             "slixmpp.plugins.xep_0050.adhoc.XEP_0050.new_session",
@@ -1150,97 +1166,6 @@ class TestAimShakespeareBase(Base):
         )
 
 
-class TestPrivilegeOld(ClearSessionMixin, SlidgeTest):
-    plugin = globals()
-
-    def setUp(self):
-        super().setUp()
-        self.xmpp.store.users.new(
-            JID("romeo@shakespeare.lit/gajim"), {"username": "romeo", "city": ""}
-        )
-
-    def test_privilege_old(self):
-        assert (
-            self.xmpp["xep_0356"].granted_privileges["shakespeare.lit"] == Permissions()
-        )
-        assert (
-            self.xmpp["xep_0356_old"].granted_privileges["shakespeare.lit"]
-            == Permissions()
-        )
-        self.recv(  # language=XML
-            """
-            <message to="aim.shakespeare.lit"
-                     from="shakespeare.lit">
-              <privilege xmlns="urn:xmpp:privilege:1">
-                <perm access="roster"
-                      type="both" />
-                <perm access="message"
-                      type="outgoing" />
-              </privilege>
-            </message>
-            """
-        )
-        assert (
-            self.xmpp["xep_0356_old"].granted_privileges["shakespeare.lit"].message
-            == MessagePermission.OUTGOING
-        )
-        assert (
-            self.xmpp["xep_0356_old"].granted_privileges["shakespeare.lit"].presence
-            == PresencePermission.NONE
-        )
-        assert (
-            self.xmpp["xep_0356_old"].granted_privileges["shakespeare.lit"].roster
-            == RosterAccess.BOTH
-        )
-
-        session = BaseSession.get_self_or_unique_subclass().from_jid(
-            JID("romeo@shakespeare.lit")
-        )
-        juliet = self.run_coro(
-            session.contacts.by_jid(JID("juliet@aim.shakespeare.lit"))
-        )
-        juliet.send_text("body", 444, carbon=True)
-        self.send(  # language=XML
-            """
-            <message to="shakespeare.lit"
-                     from="aim.shakespeare.lit">
-              <privilege xmlns="urn:xmpp:privilege:1">
-                <forwarded xmlns="urn:xmpp:forward:0">
-                  <message xmlns="jabber:client"
-                           to="juliet@aim.shakespeare.lit"
-                           type="chat"
-                           from="romeo@shakespeare.lit"
-                           id="444">
-                    <body>body</body>
-                    <store xmlns="urn:xmpp:hints" />
-                    <active xmlns="http://jabber.org/protocol/chatstates" />
-                    <markable xmlns="urn:xmpp:chat-markers:0" />
-                  </message>
-                </forwarded>
-              </privilege>
-            </message>
-            """,
-        )
-        juliet.is_friend = True
-        self.xmpp.loop.create_task(juliet.add_to_roster())
-        self.send(  # language=XML
-            """
-            <iq xmlns="jabber:component:accept"
-                type="set"
-                to="romeo@shakespeare.lit"
-                from="aim.shakespeare.lit"
-                id="1">
-              <query xmlns="jabber:iq:roster">
-                <item subscription="both"
-                      jid="juliet@aim.shakespeare.lit">
-                  <group>slidge</group>
-                </item>
-              </query>
-            </iq>
-            """
-        )
-
-
 class TestPrivilege(ClearSessionMixin, SlidgeTest):
     plugin = globals()
 
@@ -1254,10 +1179,6 @@ class TestPrivilege(ClearSessionMixin, SlidgeTest):
         assert (
             self.xmpp["xep_0356"].granted_privileges["shakespeare.lit"] == Permissions()
         )
-        assert (
-            self.xmpp["xep_0356_old"].granted_privileges["shakespeare.lit"]
-            == Permissions()
-        )
         self.recv(  # language=XML
             """
             <message to="aim.shakespeare.lit"
